@@ -38,8 +38,7 @@ def get_distinguished_name():
             logger.warning("arcproxy experienced a problem (will try voms-proxy-info instead)")
 
             # Default to voms-proxy-info
-            executable = 'voms-proxy-info -subject'
-            exit_code, stdout, stderr = execute(executable)
+            exit_code, stdout, stderr = vomsproxyinfo(options='-subject', mute=True)
 
     if exit_code == 0:
         dn = stdout
@@ -55,6 +54,26 @@ def get_distinguished_name():
     return dn
 
 
+def vomsproxyinfo(options='-all', mute=False, path=''):
+    """
+    Execute voms-proxy-info with the given options.
+
+    :param options: command options (string).
+    :param mute: should command output be printed (mute=False).
+    :param path: use given path if specified for proxy (string).
+    :return: exit code (int), stdout (string), stderr (string).
+    """
+
+    executable = f'voms-proxy-info {options}'
+    if path:
+        executable += f' --file={path}'
+    exit_code, stdout, stderr = execute(executable)
+    if not mute:
+        logger.info(stdout + stderr)
+
+    return exit_code, stdout, stderr
+
+
 def get_proxy(proxy_outfile_name, voms_role):
     """
     Download and store a proxy.
@@ -83,6 +102,10 @@ def get_proxy(proxy_outfile_name, voms_role):
     except Exception as exc:
         logger.error(f"Get proxy from panda server failed: {exc}, {traceback.format_exc()}")
         return False, proxy_outfile_name
+    else:
+        # dump voms-proxy-info -all to log
+        if res and res['StatusCode'] == 0:
+            _, _, _ = vomsproxyinfo(options='-all', path=proxy_outfile_name)
 
     def create_file(filename, contents):
         """
